==> Paws-0.16.tar.gz: Paws-0.16/lib/Paws/ImportExport/CreateJob.pm <==

package Paws::ImportExport::CreateJob;
  use Moose;
  has APIVersion => (is => 'ro', isa => 'Str');
  has JobType => (is => 'ro', isa => 'Str', required => 1);
  has Manifest => (is => 'ro', isa => 'Str', required => 1);
  has ManifestAddendum => (is => 'ro', isa => 'Str');
  has ValidateOnly => (is => 'ro', isa => 'Bool', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateJob');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ImportExport::CreateJobOutput');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'CreateJobResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ImportExport::CreateJob - Arguments for method CreateJob on Paws::ImportExport

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateJob on the 
AWS Import/Export service. Use the attributes of this class
as arguments to method CreateJob.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to CreateJob.

As an example:

  $service_obj->CreateJob(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 APIVersion => Str

  

=head2 B<REQUIRED> JobType => Str

  

=head2 B<REQUIRED> Manifest => Str

  

=head2 ManifestAddendum => Str

  

=head2 B<REQUIRED> ValidateOnly => Bool

  



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateJob in L<Paws::ImportExport>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.17.tar.gz: Paws-0.17/lib/Paws/ImportExport/CreateJob.pm <==

package Paws::ImportExport::CreateJob;
  use Moose;
  has APIVersion => (is => 'ro', isa => 'Str');
  has JobType => (is => 'ro', isa => 'Str', required => 1);
  has Manifest => (is => 'ro', isa => 'Str', required => 1);
  has ManifestAddendum => (is => 'ro', isa => 'Str');
  has ValidateOnly => (is => 'ro', isa => 'Bool', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateJob');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ImportExport::CreateJobOutput');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'CreateJobResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ImportExport::CreateJob - Arguments for method CreateJob on Paws::ImportExport

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateJob on the 
AWS Import/Export service. Use the attributes of this class
as arguments to method CreateJob.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CreateJob.

As an example:

  $service_obj->CreateJob(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 APIVersion => Str

  

=head2 B<REQUIRED> JobType => Str

  

=head2 B<REQUIRED> Manifest => Str

  

=head2 ManifestAddendum => Str

  

=head2 B<REQUIRED> ValidateOnly => Bool

  



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateJob in L<Paws::ImportExport>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
